Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
testrail_api_reporter/__init__.py | 9 | 0 | 0 | 100%
testrail_api_reporter/engines/__init__.py | 4 | 0 | 0 | 100%
testrail_api_reporter/engines/at_coverage_reporter.py | 156 | 142 | 0 | 9%
testrail_api_reporter/engines/case_backup.py | 48 | 38 | 0 | 21%
testrail_api_reporter/engines/plotly_reporter.py | 106 | 30 | 0 | 72%
testrail_api_reporter/engines/results_reporter.py | 302 | 266 | 0 | 12%
testrail_api_reporter/publishers/__init__.py | 4 | 0 | 0 | 100%
testrail_api_reporter/publishers/confluence_sender.py | 76 | 65 | 0 | 14%
testrail_api_reporter/publishers/email_sender.py | 154 | 131 | 0 | 15%
testrail_api_reporter/publishers/gdrive_uploader.py | 68 | 55 | 0 | 19%
testrail_api_reporter/publishers/slack_sender.py | 40 | 26 | 0 | 35%
testrail_api_reporter/utils/__init__.py | 2 | 0 | 0 | 100%
testrail_api_reporter/utils/case_stat.py | 35 | 0 | 0 | 100%
testrail_api_reporter/utils/csv_parser.py | 53 | 0 | 0 | 100%
testrail_api_reporter/utils/logger_config.py | 14 | 0 | 0 | 100%
testrail_api_reporter/utils/reporter_utils.py | 49 | 0 | 0 | 100%
Total | 1120 | 753 | 0 | 33%

No items found using the specified filter.